@@ -26,6 +26,7 @@
 #include <QFontMetrics>
 
 int PuzzleItem::moveCount_ = 0;
+bool PuzzleItem::manuallyMovable_ = false;
 
 PuzzleItem::PuzzleItem(QGraphicsItem *parent) :
         QGraphicsPixmapItem(parent)
@@ -75,7 +76,7 @@ void PuzzleItem::moveMeTo(const QPointF &location)
 
 void PuzzleItem::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
-    if(movable_) {
+    if(movable_ && manuallyMovable_) {
         moveMeTo(GameView::instance()->emptyPlace());
         QPointF tmp = currentPlace();
         setCurrentPlace(GameView::instance()->emptyPlace());
@@ -115,6 +116,11 @@ void PuzzleItem::resetMoveCount()
     moveCount_ = 0;
 }
 
+void PuzzleItem::setManuallyMovable(const bool manuallyMovable)
+{
+    manuallyMovable_ = manuallyMovable;
+}
+
 void PuzzleItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
     QGraphicsPixmapItem::paint(painter, option, widget);
@@ -164,3 +170,8 @@ bool PuzzleItem::drawNumber() const
 {
     return drawNumber_;
 }
+
+void PuzzleItem::setMoveCount(int count)
+{
+    moveCount_ = count;
+}
